/***************************************************************************
 *   Copyright (C) 2010 by Martin Burgemeister, Mathis Lindemann           *
 *                                                                         *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef SORTCONTROLLER_H_
#define SORTCONTROLLER_H_
#include "data/TableModel.h"
#include "controller/Controller.h"
/**
 * \class SortController
 * \brief Class for Sorting the table.
 *
 * This class provides methods for sorting the visible table of the
 * tablemodel. The items can be sorted according to codepoints, collations
 * (level 1) and comments.
 *
 * \author Martin Burgemeister <Martin.Burgemeister@gmx.de>,
 *         Mathis Lindemann <MathisLindemann@gmx.net>
 *
 * \version 1.0
 * \date 16 August 2010
 * \see TableModel
 */
class SortController : public Controller {

	Q_OBJECT

public:
	enum sortMode{
//		DEFAULT_ORDER   = 0x0,
		CODEPOINT_SORT = 0x1,
		COLLATION_SORT = 0x2,
		COMMENT_SORT   = 0x3
	};
	   Q_DECLARE_FLAGS(SortMode, sortMode)
	enum sortOrder{
			ASCENDING = 0x0,
			DESCENDING= 0x1
	};
	   Q_DECLARE_FLAGS(SortOrder, sortOrder)
	SortController( QObject*,TableModel *);

	void sort(SortMode sm);

	void sortOrder(SortOrder sa);

protected slots:
	void reverseTable(QList<Letter*> letters);
	static bool codepointLessThan(const Letter* l1, const Letter* l2);
	static bool collationLessThan(const Letter* l1, const Letter* l2);
	static bool commentLessThan(const Letter* l1, const Letter* l2);

private:
	/**
	 * \brief Table model.
	 */
	TableModel * model_;
	/**
	 * \brief Current sort align.
	 */
	SortOrder sa_;

signals:
	/**
	 * \brief Signal for clear the tableview.
	 */
	void clear(bool clearBlockselection);
	/**
	 * \brief Signal to add a list of letters.
	 *
	 * \param letters List of letters to add to the view.
	 */
	void addLetters(QList<Letter*> letters);
	/**
	 * \brief Change alignment of the sort.
	 */
	void toggleTableSignal(QList<Letter*> letters);
};
Q_DECLARE_OPERATORS_FOR_FLAGS(SortController::SortMode)
Q_DECLARE_OPERATORS_FOR_FLAGS(SortController::SortOrder)

#endif
