/***************************************************************************
 *   Copyright (C) 2010 by Martin Burgemeister, Mathis Lindemann		   *
 *      																   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#include "UCTools.h"
/**
 * \brief Format a codepoint uint to 0x hexcode string.
 *
 * \param cp The codepoint to format
 * \return Codepoint formatted like 0000.
 */
QString UCTools::formatCodepoint ( uint cp )
{
    QString string ( QString::number ( cp, 16 ) );
    while ( string.length () < 4 )
    {
        string.prepend ( '0' );
    }
    return string.toUpper ();
}

/**
 * \brief Converts Unicode into QString (Glyph) for output.
 *
 * Takes care of the conversion into UTF-16, regarding the surrogates.
 *
 * \param code The unicode to convert.
 * \return The encoded glyph in a QString.
 */
QString UCTools::unicodeToString ( uint code )
{
    QString tmp;
    if ( code > 65535 )
    {
        QChar low  ( QChar::lowSurrogate  ( code ) );
        QChar high ( QChar::highSurrogate ( code ) );

        tmp.append ( high );
        tmp.append ( low );
    } else
    {
        tmp.append ( QChar ( code ) );
    }
    return tmp;
}
